@@ -106,13 +106,13 @@ def markScriptWithRareWordsTimestamp(nlp, script, subs):
     )
     subsDistinctTimestamp = getDistinctWordsTimestampSubs(subsLemma, subsDistinct)
 
-    # file0 = open("subHelp.json", "w+")
-    # json.dump(subsDistinct, file0, indent=4)
-    # file0 = open("scriptHelp.json", "w+")
-    # json.dump(scriptDistinct, file0, indent=4)
-    # file0 = open("matchingHelp.json", "w+")
-    # json.dump(matchingDistinct, file0, indent=4)
-    # file0 = open("test.json", "w+")
-    # json.dump(scriptDistinctTimestamp, file0, indent=4)
+    file0 = open("subHelp.json", "w+")
+    json.dump(subsDistinct, file0, indent=4)
+    file0 = open("scriptHelp.json", "w+")
+    json.dump(scriptDistinct, file0, indent=4)
+    file0 = open("matchingHelp.json", "w+")
+    json.dump(matchingDistinct, file0, indent=4)
+    file0 = open("test.json", "w+")
+    json.dump(scriptDistinctTimestamp, file0, indent=4)
 
     return (script, scriptDistinctTimestamp, subsDistinctTimestamp)
