@@ -2,6 +2,7 @@ import copy
 
 
 def nestedShit(pureScript, fill, prevPageIndex, prevContentIndex, prevSceneIndex):
+    prevTimestamp = [0, 0]
     while prevPageIndex < len(pureScript):
         page = pureScript[prevPageIndex]
         while prevContentIndex < len(page["content"]):
@@ -27,14 +28,24 @@ def nestedShit(pureScript, fill, prevPageIndex, prevContentIndex, prevSceneIndex
                             or scene["type"] == "TRANSITION"
                             and "CONTINUED" not in scene["content"]["text"]
                         ):
-                            scene["duration"] = fill
+                            scene["timestamp"] = [
+                                prevTimestamp[1],
+                                prevTimestamp[1] + fill,
+                            ]
                         else:
-                            scene["duration"] = 0.0
-
+                            scene["timestamp"] = [
+                                prevTimestamp[1],
+                                prevTimestamp[1],
+                            ]
                     prevSceneIndex += 1
+                    prevTimestamp = scene["timestamp"]
                 prevSceneIndex = 0
             else:
-                content["duration"] = fill
+                content["timestamp"] = [
+                    prevTimestamp[1],
+                    prevTimestamp[1] + fill,
+                ]
+                prevTimestamp = content["timestamp"]
             prevContentIndex += 1
         prevContentIndex = 0
         prevPageIndex += 1
@@ -73,7 +84,8 @@ def fillTimestamps(pureScript):
                     fill = scene["timestamp"][0] - startTimestamp[1]
                     fill = fill / countInBetween if countInBetween > 0 else 0
 
-                    scene["duration"] = scene["timestamp"][1] - scene["timestamp"][0]
+                    if fill < 0:
+                        fill = 1.5
 
                     if countInBetween > 0:
                         pureScript = nestedShit(
