@@ -4,19 +4,6 @@
 def tagTimestampToScript(pureScript, scriptWithTimestamp):
     for line in scriptWithTimestamp:
         if (
-            # any(
-            #     [
-            #         line["dialogue"]
-            #         in " ".join(
-            #             list(
-            #                 filter(
-            #                     lambda x: "(" != x[0], testDialogue,
-            #                 )
-            #             )
-            #         ).lower()
-            #         for testDialogue in testDialogues
-            #     ]
-            # )
             "timestamp" in line
         ):
             # isolatedLeftWords = line["dialogue"][0:line["distinct"]["matchIndex"]]
@@ -37,10 +24,6 @@ def tagTimestampToScript(pureScript, scriptWithTimestamp):
             #         sceneIndex
             #     ]["timestamp"][0], line["timestamp"][1]]
             # else:
-            pureScript[line["pageIndex"]]["content"][line["sceneIndex"]]["scene"][
-                line["sectionIndex"]
-            ]["timestampOriginal"] = line["timestamp"]
-            
             pureScript[line["pageIndex"]]["content"][line["sceneIndex"]]["scene"][
                 line["sectionIndex"]
             ]["timestamp"] = [line["timestamp"][0], line["timestamp"][1]]
